#Check for grades

A simple script to check if a site changed or not which can mean that your teacher updated the grades.

Use it as a script with arguemnts url and optional what music_url you want to play on change.

import grades